# Generated by Django 5.1.1 on 2024-09-11 04:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('gmail_oauth_backend', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='refreshtoken',
            name='value',
            field=models.CharField(max_length=200),
        ),
    ]
